Upgrade Notes
=============

Upgrading from version 0.X.X to version 1.X.X
---------------------------------------------

When upgrading from a version in the ``0.X.X`` series to ``1.X.X`` you need to
replace the old ``api-paste.ini`` configuration (as described in :ref:`pipeline-examples`)

